# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetPolicyDocumentResult',
    'AwaitableGetPolicyDocumentResult',
    'get_policy_document',
    'get_policy_document_output',
]

@pulumi.output_type
class GetPolicyDocumentResult:
    """
    A collection of values returned by getPolicyDocument.
    """
    def __init__(__self__, document=None, id=None, output_file=None, statements=None, version=None):
        if document and not isinstance(document, str):
            raise TypeError("Expected argument 'document' to be a str")
        pulumi.set(__self__, "document", document)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if statements and not isinstance(statements, list):
            raise TypeError("Expected argument 'statements' to be a list")
        pulumi.set(__self__, "statements", statements)
        if version and not isinstance(version, str):
            raise TypeError("Expected argument 'version' to be a str")
        pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter
    def document(self) -> str:
        """
        Standard policy document rendered based on the arguments above.
        """
        return pulumi.get(self, "document")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def statements(self) -> Optional[Sequence['outputs.GetPolicyDocumentStatementResult']]:
        return pulumi.get(self, "statements")

    @property
    @pulumi.getter
    def version(self) -> Optional[str]:
        return pulumi.get(self, "version")


class AwaitableGetPolicyDocumentResult(GetPolicyDocumentResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPolicyDocumentResult(
            document=self.document,
            id=self.id,
            output_file=self.output_file,
            statements=self.statements,
            version=self.version)


def get_policy_document(output_file: Optional[str] = None,
                        statements: Optional[Sequence[Union['GetPolicyDocumentStatementArgs', 'GetPolicyDocumentStatementArgsDict']]] = None,
                        version: Optional[str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPolicyDocumentResult:
    """
    This data source Generates a RAM policy document of the current Alibaba Cloud user.

    > **NOTE:** Available since v1.184.0+.

    ## Example Usage

    ### Basic Example

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    basic_example = alicloud.ram.get_policy_document(version="1",
        statements=[{
            "effect": "Allow",
            "actions": ["oss:*"],
            "resources": [
                "acs:oss:*:*:myphotos",
                "acs:oss:*:*:myphotos/*",
            ],
        }])
    default = alicloud.ram.Policy("default",
        policy_name="tf-example",
        policy_document=basic_example.document,
        force=True)
    ```

    `data.alicloud_ram_policy_document.basic_example.document` will evaluate to:

    ### Example Multiple Condition Keys and Values

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    multiple_condition = alicloud.ram.get_policy_document(version="1",
        statements=[
            {
                "effect": "Allow",
                "actions": [
                    "oss:ListBuckets",
                    "oss:GetBucketStat",
                    "oss:GetBucketInfo",
                    "oss:GetBucketTagging",
                    "oss:GetBucketAcl",
                ],
                "resources": ["acs:oss:*:*:*"],
            },
            {
                "effect": "Allow",
                "actions": [
                    "oss:GetObject",
                    "oss:GetObjectAcl",
                ],
                "resources": ["acs:oss:*:*:myphotos/hangzhou/2015/*"],
            },
            {
                "effect": "Allow",
                "actions": ["oss:ListObjects"],
                "resources": ["acs:oss:*:*:myphotos"],
                "conditions": [
                    {
                        "operator": "StringLike",
                        "variable": "oss:Delimiter",
                        "values": ["/"],
                    },
                    {
                        "operator": "StringLike",
                        "variable": "oss:Prefix",
                        "values": [
                            "",
                            "hangzhou/",
                            "hangzhou/2015/*",
                        ],
                    },
                ],
            },
        ])
    policy = alicloud.ram.Policy("policy",
        policy_name="tf-example-condition",
        policy_document=multiple_condition.document,
        force=True)
    ```

    `data.alicloud_ram_policy_document.multiple_condition.document` will evaluate to:

    ### Example Assume-Role Policy with RAM Principal

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ram_example = alicloud.ram.get_policy_document(statements=[{
        "effect": "Allow",
        "actions": ["sts:AssumeRole"],
        "principals": [{
            "entity": "RAM",
            "identifiers": ["acs:ram::123456789012****:root"],
        }],
    }])
    role = alicloud.ram.Role("role",
        name="tf-example-role-ram",
        document=ram_example.document,
        force=True)
    ```

    `data.alicloud_ram_policy_document.ram_example.document` will evaluate to:

    ### Example Assume-Role Policy with Service Principal

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    service_example = alicloud.ram.get_policy_document(statements=[{
        "effect": "Allow",
        "actions": ["sts:AssumeRole"],
        "principals": [{
            "entity": "Service",
            "identifiers": ["ecs.aliyuncs.com"],
        }],
    }])
    role = alicloud.ram.Role("role",
        name="tf-example-role-service",
        document=service_example.document,
        force=True)
    ```

    `data.alicloud_ram_policy_document.service_example.document` will evaluate to:

    ### Example Assume-Role Policy with Federated Principal

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    federated_example = alicloud.ram.get_policy_document(statements=[{
        "effect": "Allow",
        "actions": ["sts:AssumeRole"],
        "principals": [{
            "entity": "Federated",
            "identifiers": ["acs:ram::123456789012****:saml-provider/testprovider"],
        }],
        "conditions": [{
            "operator": "StringEquals",
            "variable": "saml:recipient",
            "values": ["https://signin.aliyun.com/saml-role/sso"],
        }],
    }])
    role = alicloud.ram.Role("role",
        name="tf-example-role-federated",
        document=federated_example.document,
        force=True)
    ```

    `data.alicloud_ram_policy_document.federated_example.document` will evaluate to:


    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param Sequence[Union['GetPolicyDocumentStatementArgs', 'GetPolicyDocumentStatementArgsDict']] statements: Statement of the RAM policy document. See the following `Block statement`. See `statement` below.
    :param str version: Version of the RAM policy document. Valid value is `1`. Default value is `1`.
    """
    __args__ = dict()
    __args__['outputFile'] = output_file
    __args__['statements'] = statements
    __args__['version'] = version
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:ram/getPolicyDocument:getPolicyDocument', __args__, opts=opts, typ=GetPolicyDocumentResult).value

    return AwaitableGetPolicyDocumentResult(
        document=pulumi.get(__ret__, 'document'),
        id=pulumi.get(__ret__, 'id'),
        output_file=pulumi.get(__ret__, 'output_file'),
        statements=pulumi.get(__ret__, 'statements'),
        version=pulumi.get(__ret__, 'version'))
def get_policy_document_output(output_file: Optional[pulumi.Input[Optional[str]]] = None,
                               statements: Optional[pulumi.Input[Optional[Sequence[Union['GetPolicyDocumentStatementArgs', 'GetPolicyDocumentStatementArgsDict']]]]] = None,
                               version: Optional[pulumi.Input[Optional[str]]] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetPolicyDocumentResult]:
    """
    This data source Generates a RAM policy document of the current Alibaba Cloud user.

    > **NOTE:** Available since v1.184.0+.

    ## Example Usage

    ### Basic Example

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    basic_example = alicloud.ram.get_policy_document(version="1",
        statements=[{
            "effect": "Allow",
            "actions": ["oss:*"],
            "resources": [
                "acs:oss:*:*:myphotos",
                "acs:oss:*:*:myphotos/*",
            ],
        }])
    default = alicloud.ram.Policy("default",
        policy_name="tf-example",
        policy_document=basic_example.document,
        force=True)
    ```

    `data.alicloud_ram_policy_document.basic_example.document` will evaluate to:

    ### Example Multiple Condition Keys and Values

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    multiple_condition = alicloud.ram.get_policy_document(version="1",
        statements=[
            {
                "effect": "Allow",
                "actions": [
                    "oss:ListBuckets",
                    "oss:GetBucketStat",
                    "oss:GetBucketInfo",
                    "oss:GetBucketTagging",
                    "oss:GetBucketAcl",
                ],
                "resources": ["acs:oss:*:*:*"],
            },
            {
                "effect": "Allow",
                "actions": [
                    "oss:GetObject",
                    "oss:GetObjectAcl",
                ],
                "resources": ["acs:oss:*:*:myphotos/hangzhou/2015/*"],
            },
            {
                "effect": "Allow",
                "actions": ["oss:ListObjects"],
                "resources": ["acs:oss:*:*:myphotos"],
                "conditions": [
                    {
                        "operator": "StringLike",
                        "variable": "oss:Delimiter",
                        "values": ["/"],
                    },
                    {
                        "operator": "StringLike",
                        "variable": "oss:Prefix",
                        "values": [
                            "",
                            "hangzhou/",
                            "hangzhou/2015/*",
                        ],
                    },
                ],
            },
        ])
    policy = alicloud.ram.Policy("policy",
        policy_name="tf-example-condition",
        policy_document=multiple_condition.document,
        force=True)
    ```

    `data.alicloud_ram_policy_document.multiple_condition.document` will evaluate to:

    ### Example Assume-Role Policy with RAM Principal

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ram_example = alicloud.ram.get_policy_document(statements=[{
        "effect": "Allow",
        "actions": ["sts:AssumeRole"],
        "principals": [{
            "entity": "RAM",
            "identifiers": ["acs:ram::123456789012****:root"],
        }],
    }])
    role = alicloud.ram.Role("role",
        name="tf-example-role-ram",
        document=ram_example.document,
        force=True)
    ```

    `data.alicloud_ram_policy_document.ram_example.document` will evaluate to:

    ### Example Assume-Role Policy with Service Principal

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    service_example = alicloud.ram.get_policy_document(statements=[{
        "effect": "Allow",
        "actions": ["sts:AssumeRole"],
        "principals": [{
            "entity": "Service",
            "identifiers": ["ecs.aliyuncs.com"],
        }],
    }])
    role = alicloud.ram.Role("role",
        name="tf-example-role-service",
        document=service_example.document,
        force=True)
    ```

    `data.alicloud_ram_policy_document.service_example.document` will evaluate to:

    ### Example Assume-Role Policy with Federated Principal

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    federated_example = alicloud.ram.get_policy_document(statements=[{
        "effect": "Allow",
        "actions": ["sts:AssumeRole"],
        "principals": [{
            "entity": "Federated",
            "identifiers": ["acs:ram::123456789012****:saml-provider/testprovider"],
        }],
        "conditions": [{
            "operator": "StringEquals",
            "variable": "saml:recipient",
            "values": ["https://signin.aliyun.com/saml-role/sso"],
        }],
    }])
    role = alicloud.ram.Role("role",
        name="tf-example-role-federated",
        document=federated_example.document,
        force=True)
    ```

    `data.alicloud_ram_policy_document.federated_example.document` will evaluate to:


    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param Sequence[Union['GetPolicyDocumentStatementArgs', 'GetPolicyDocumentStatementArgsDict']] statements: Statement of the RAM policy document. See the following `Block statement`. See `statement` below.
    :param str version: Version of the RAM policy document. Valid value is `1`. Default value is `1`.
    """
    __args__ = dict()
    __args__['outputFile'] = output_file
    __args__['statements'] = statements
    __args__['version'] = version
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:ram/getPolicyDocument:getPolicyDocument', __args__, opts=opts, typ=GetPolicyDocumentResult)
    return __ret__.apply(lambda __response__: GetPolicyDocumentResult(
        document=pulumi.get(__response__, 'document'),
        id=pulumi.get(__response__, 'id'),
        output_file=pulumi.get(__response__, 'output_file'),
        statements=pulumi.get(__response__, 'statements'),
        version=pulumi.get(__response__, 'version')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['DatabaseArgs', 'Database']

@pulumi.input_type
class DatabaseArgs:
    def __init__(__self__, *,
                 database_name: pulumi.Input[str],
                 db_instance_id: pulumi.Input[str],
                 owner: pulumi.Input[str],
                 character_set_name: Optional[pulumi.Input[str]] = None,
                 collate: Optional[pulumi.Input[str]] = None,
                 ctype: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Database resource.
        :param pulumi.Input[str] database_name: Database Name
        :param pulumi.Input[str] db_instance_id: Instance ID
        :param pulumi.Input[str] owner: Data Sheet owner
        :param pulumi.Input[str] character_set_name: Character set, default value is UTF8
        :param pulumi.Input[str] collate: Database locale parameters, specifying string comparison/collation
        :param pulumi.Input[str] ctype: Database locale parameters, specifying character classification/case conversion rules
        :param pulumi.Input[str] description: Database Description
        """
        pulumi.set(__self__, "database_name", database_name)
        pulumi.set(__self__, "db_instance_id", db_instance_id)
        pulumi.set(__self__, "owner", owner)
        if character_set_name is not None:
            pulumi.set(__self__, "character_set_name", character_set_name)
        if collate is not None:
            pulumi.set(__self__, "collate", collate)
        if ctype is not None:
            pulumi.set(__self__, "ctype", ctype)
        if description is not None:
            pulumi.set(__self__, "description", description)

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> pulumi.Input[str]:
        """
        Database Name
        """
        return pulumi.get(self, "database_name")

    @database_name.setter
    def database_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "database_name", value)

    @property
    @pulumi.getter(name="dbInstanceId")
    def db_instance_id(self) -> pulumi.Input[str]:
        """
        Instance ID
        """
        return pulumi.get(self, "db_instance_id")

    @db_instance_id.setter
    def db_instance_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "db_instance_id", value)

    @property
    @pulumi.getter
    def owner(self) -> pulumi.Input[str]:
        """
        Data Sheet owner
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: pulumi.Input[str]):
        pulumi.set(self, "owner", value)

    @property
    @pulumi.getter(name="characterSetName")
    def character_set_name(self) -> Optional[pulumi.Input[str]]:
        """
        Character set, default value is UTF8
        """
        return pulumi.get(self, "character_set_name")

    @character_set_name.setter
    def character_set_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "character_set_name", value)

    @property
    @pulumi.getter
    def collate(self) -> Optional[pulumi.Input[str]]:
        """
        Database locale parameters, specifying string comparison/collation
        """
        return pulumi.get(self, "collate")

    @collate.setter
    def collate(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "collate", value)

    @property
    @pulumi.getter
    def ctype(self) -> Optional[pulumi.Input[str]]:
        """
        Database locale parameters, specifying character classification/case conversion rules
        """
        return pulumi.get(self, "ctype")

    @ctype.setter
    def ctype(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ctype", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Database Description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)


@pulumi.input_type
class _DatabaseState:
    def __init__(__self__, *,
                 character_set_name: Optional[pulumi.Input[str]] = None,
                 collate: Optional[pulumi.Input[str]] = None,
                 ctype: Optional[pulumi.Input[str]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 db_instance_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 owner: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Database resources.
        :param pulumi.Input[str] character_set_name: Character set, default value is UTF8
        :param pulumi.Input[str] collate: Database locale parameters, specifying string comparison/collation
        :param pulumi.Input[str] ctype: Database locale parameters, specifying character classification/case conversion rules
        :param pulumi.Input[str] database_name: Database Name
        :param pulumi.Input[str] db_instance_id: Instance ID
        :param pulumi.Input[str] description: Database Description
        :param pulumi.Input[str] owner: Data Sheet owner
        """
        if character_set_name is not None:
            pulumi.set(__self__, "character_set_name", character_set_name)
        if collate is not None:
            pulumi.set(__self__, "collate", collate)
        if ctype is not None:
            pulumi.set(__self__, "ctype", ctype)
        if database_name is not None:
            pulumi.set(__self__, "database_name", database_name)
        if db_instance_id is not None:
            pulumi.set(__self__, "db_instance_id", db_instance_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)

    @property
    @pulumi.getter(name="characterSetName")
    def character_set_name(self) -> Optional[pulumi.Input[str]]:
        """
        Character set, default value is UTF8
        """
        return pulumi.get(self, "character_set_name")

    @character_set_name.setter
    def character_set_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "character_set_name", value)

    @property
    @pulumi.getter
    def collate(self) -> Optional[pulumi.Input[str]]:
        """
        Database locale parameters, specifying string comparison/collation
        """
        return pulumi.get(self, "collate")

    @collate.setter
    def collate(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "collate", value)

    @property
    @pulumi.getter
    def ctype(self) -> Optional[pulumi.Input[str]]:
        """
        Database locale parameters, specifying character classification/case conversion rules
        """
        return pulumi.get(self, "ctype")

    @ctype.setter
    def ctype(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ctype", value)

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> Optional[pulumi.Input[str]]:
        """
        Database Name
        """
        return pulumi.get(self, "database_name")

    @database_name.setter
    def database_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "database_name", value)

    @property
    @pulumi.getter(name="dbInstanceId")
    def db_instance_id(self) -> Optional[pulumi.Input[str]]:
        """
        Instance ID
        """
        return pulumi.get(self, "db_instance_id")

    @db_instance_id.setter
    def db_instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "db_instance_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Database Description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[str]]:
        """
        Data Sheet owner
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "owner", value)


class Database(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 character_set_name: Optional[pulumi.Input[str]] = None,
                 collate: Optional[pulumi.Input[str]] = None,
                 ctype: Optional[pulumi.Input[str]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 db_instance_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 owner: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a GPDB Database resource.

        For information about GPDB Database and how to use it, see [What is Database](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.232.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default35_okx_y = alicloud.vpc.Network("default35OkxY", cidr_block="192.168.0.0/16")
        defaultl8ha_q3 = alicloud.vpc.Switch("defaultl8haQ3",
            vpc_id=default35_okx_y.id,
            zone_id="cn-beijing-h",
            cidr_block="192.168.1.0/24")
        default_tc08a9 = alicloud.gpdb.Instance("defaultTC08a9",
            instance_spec="2C8G",
            seg_node_num=2,
            seg_storage_type="cloud_essd",
            instance_network_type="VPC",
            db_instance_category="Basic",
            payment_type="PayAsYouGo",
            ssl_enabled=0,
            engine_version="6.0",
            engine="gpdb",
            zone_id="cn-beijing-h",
            vswitch_id=defaultl8ha_q3.id,
            storage_size=50,
            master_cu=4,
            vpc_id=default35_okx_y.id,
            db_instance_mode="StorageElastic")
        default = alicloud.gpdb.Database("default",
            character_set_name="UTF8",
            owner="adbpgadmin",
            description="go-to-the-docks-for-french-fries",
            database_name="seagull",
            collate="en_US.utf8",
            ctype="en_US.utf8",
            db_instance_id=default_tc08a9.id)
        ```

        ## Import

        GPDB Database can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:gpdb/database:Database example <db_instance_id>:<database_name>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] character_set_name: Character set, default value is UTF8
        :param pulumi.Input[str] collate: Database locale parameters, specifying string comparison/collation
        :param pulumi.Input[str] ctype: Database locale parameters, specifying character classification/case conversion rules
        :param pulumi.Input[str] database_name: Database Name
        :param pulumi.Input[str] db_instance_id: Instance ID
        :param pulumi.Input[str] description: Database Description
        :param pulumi.Input[str] owner: Data Sheet owner
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DatabaseArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a GPDB Database resource.

        For information about GPDB Database and how to use it, see [What is Database](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.232.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default35_okx_y = alicloud.vpc.Network("default35OkxY", cidr_block="192.168.0.0/16")
        defaultl8ha_q3 = alicloud.vpc.Switch("defaultl8haQ3",
            vpc_id=default35_okx_y.id,
            zone_id="cn-beijing-h",
            cidr_block="192.168.1.0/24")
        default_tc08a9 = alicloud.gpdb.Instance("defaultTC08a9",
            instance_spec="2C8G",
            seg_node_num=2,
            seg_storage_type="cloud_essd",
            instance_network_type="VPC",
            db_instance_category="Basic",
            payment_type="PayAsYouGo",
            ssl_enabled=0,
            engine_version="6.0",
            engine="gpdb",
            zone_id="cn-beijing-h",
            vswitch_id=defaultl8ha_q3.id,
            storage_size=50,
            master_cu=4,
            vpc_id=default35_okx_y.id,
            db_instance_mode="StorageElastic")
        default = alicloud.gpdb.Database("default",
            character_set_name="UTF8",
            owner="adbpgadmin",
            description="go-to-the-docks-for-french-fries",
            database_name="seagull",
            collate="en_US.utf8",
            ctype="en_US.utf8",
            db_instance_id=default_tc08a9.id)
        ```

        ## Import

        GPDB Database can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:gpdb/database:Database example <db_instance_id>:<database_name>
        ```

        :param str resource_name: The name of the resource.
        :param DatabaseArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DatabaseArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 character_set_name: Optional[pulumi.Input[str]] = None,
                 collate: Optional[pulumi.Input[str]] = None,
                 ctype: Optional[pulumi.Input[str]] = None,
                 database_name: Optional[pulumi.Input[str]] = None,
                 db_instance_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 owner: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DatabaseArgs.__new__(DatabaseArgs)

            __props__.__dict__["character_set_name"] = character_set_name
            __props__.__dict__["collate"] = collate
            __props__.__dict__["ctype"] = ctype
            if database_name is None and not opts.urn:
                raise TypeError("Missing required property 'database_name'")
            __props__.__dict__["database_name"] = database_name
            if db_instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'db_instance_id'")
            __props__.__dict__["db_instance_id"] = db_instance_id
            __props__.__dict__["description"] = description
            if owner is None and not opts.urn:
                raise TypeError("Missing required property 'owner'")
            __props__.__dict__["owner"] = owner
        super(Database, __self__).__init__(
            'alicloud:gpdb/database:Database',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            character_set_name: Optional[pulumi.Input[str]] = None,
            collate: Optional[pulumi.Input[str]] = None,
            ctype: Optional[pulumi.Input[str]] = None,
            database_name: Optional[pulumi.Input[str]] = None,
            db_instance_id: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            owner: Optional[pulumi.Input[str]] = None) -> 'Database':
        """
        Get an existing Database resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] character_set_name: Character set, default value is UTF8
        :param pulumi.Input[str] collate: Database locale parameters, specifying string comparison/collation
        :param pulumi.Input[str] ctype: Database locale parameters, specifying character classification/case conversion rules
        :param pulumi.Input[str] database_name: Database Name
        :param pulumi.Input[str] db_instance_id: Instance ID
        :param pulumi.Input[str] description: Database Description
        :param pulumi.Input[str] owner: Data Sheet owner
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DatabaseState.__new__(_DatabaseState)

        __props__.__dict__["character_set_name"] = character_set_name
        __props__.__dict__["collate"] = collate
        __props__.__dict__["ctype"] = ctype
        __props__.__dict__["database_name"] = database_name
        __props__.__dict__["db_instance_id"] = db_instance_id
        __props__.__dict__["description"] = description
        __props__.__dict__["owner"] = owner
        return Database(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="characterSetName")
    def character_set_name(self) -> pulumi.Output[Optional[str]]:
        """
        Character set, default value is UTF8
        """
        return pulumi.get(self, "character_set_name")

    @property
    @pulumi.getter
    def collate(self) -> pulumi.Output[Optional[str]]:
        """
        Database locale parameters, specifying string comparison/collation
        """
        return pulumi.get(self, "collate")

    @property
    @pulumi.getter
    def ctype(self) -> pulumi.Output[Optional[str]]:
        """
        Database locale parameters, specifying character classification/case conversion rules
        """
        return pulumi.get(self, "ctype")

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> pulumi.Output[str]:
        """
        Database Name
        """
        return pulumi.get(self, "database_name")

    @property
    @pulumi.getter(name="dbInstanceId")
    def db_instance_id(self) -> pulumi.Output[str]:
        """
        Instance ID
        """
        return pulumi.get(self, "db_instance_id")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        Database Description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def owner(self) -> pulumi.Output[str]:
        """
        Data Sheet owner
        """
        return pulumi.get(self, "owner")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['TrafficQosArgs', 'TrafficQos']

@pulumi.input_type
class TrafficQosArgs:
    def __init__(__self__, *,
                 qos_description: Optional[pulumi.Input[str]] = None,
                 qos_name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a TrafficQos resource.
        :param pulumi.Input[str] qos_description: The description of the QoS policy.  The length is **0** to **256** characters and cannot start with 'http:// 'or 'https.
        :param pulumi.Input[str] qos_name: The name of the QoS policy.  The length is **0** to **128** characters and cannot start with 'http:// 'or 'https.
        """
        if qos_description is not None:
            pulumi.set(__self__, "qos_description", qos_description)
        if qos_name is not None:
            pulumi.set(__self__, "qos_name", qos_name)

    @property
    @pulumi.getter(name="qosDescription")
    def qos_description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the QoS policy.  The length is **0** to **256** characters and cannot start with 'http:// 'or 'https.
        """
        return pulumi.get(self, "qos_description")

    @qos_description.setter
    def qos_description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "qos_description", value)

    @property
    @pulumi.getter(name="qosName")
    def qos_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the QoS policy.  The length is **0** to **128** characters and cannot start with 'http:// 'or 'https.
        """
        return pulumi.get(self, "qos_name")

    @qos_name.setter
    def qos_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "qos_name", value)


@pulumi.input_type
class _TrafficQosState:
    def __init__(__self__, *,
                 qos_description: Optional[pulumi.Input[str]] = None,
                 qos_name: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering TrafficQos resources.
        :param pulumi.Input[str] qos_description: The description of the QoS policy.  The length is **0** to **256** characters and cannot start with 'http:// 'or 'https.
        :param pulumi.Input[str] qos_name: The name of the QoS policy.  The length is **0** to **128** characters and cannot start with 'http:// 'or 'https.
        :param pulumi.Input[str] status: The status of the QoS policy. Value:
               > **NOTE:**  QoS in the configuration state will restrict the creation, update, and deletion of most QoS policies, QoS queues, and QoS rules.
        """
        if qos_description is not None:
            pulumi.set(__self__, "qos_description", qos_description)
        if qos_name is not None:
            pulumi.set(__self__, "qos_name", qos_name)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="qosDescription")
    def qos_description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the QoS policy.  The length is **0** to **256** characters and cannot start with 'http:// 'or 'https.
        """
        return pulumi.get(self, "qos_description")

    @qos_description.setter
    def qos_description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "qos_description", value)

    @property
    @pulumi.getter(name="qosName")
    def qos_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the QoS policy.  The length is **0** to **128** characters and cannot start with 'http:// 'or 'https.
        """
        return pulumi.get(self, "qos_name")

    @qos_name.setter
    def qos_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "qos_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the QoS policy. Value:
        > **NOTE:**  QoS in the configuration state will restrict the creation, update, and deletion of most QoS policies, QoS queues, and QoS rules.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


class TrafficQos(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 qos_description: Optional[pulumi.Input[str]] = None,
                 qos_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Express Connect Traffic Qos resource. Express Connect Traffic QoS Policy.

        For information about Express Connect Traffic Qos and how to use it, see [What is Traffic Qos](https://next.api.alibabacloud.com/document/Vpc/2016-04-28/CreateExpressConnectTrafficQos).

        > **NOTE:** Available since v1.224.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.expressconnect.get_physical_connections(name_regex="preserved-NODELETING")
        create_qos = alicloud.expressconnect.TrafficQos("createQos",
            qos_name=name,
            qos_description="terraform-example")
        ```

        ## Import

        Express Connect Traffic Qos can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:expressconnect/trafficQos:TrafficQos example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] qos_description: The description of the QoS policy.  The length is **0** to **256** characters and cannot start with 'http:// 'or 'https.
        :param pulumi.Input[str] qos_name: The name of the QoS policy.  The length is **0** to **128** characters and cannot start with 'http:// 'or 'https.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[TrafficQosArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Express Connect Traffic Qos resource. Express Connect Traffic QoS Policy.

        For information about Express Connect Traffic Qos and how to use it, see [What is Traffic Qos](https://next.api.alibabacloud.com/document/Vpc/2016-04-28/CreateExpressConnectTrafficQos).

        > **NOTE:** Available since v1.224.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.expressconnect.get_physical_connections(name_regex="preserved-NODELETING")
        create_qos = alicloud.expressconnect.TrafficQos("createQos",
            qos_name=name,
            qos_description="terraform-example")
        ```

        ## Import

        Express Connect Traffic Qos can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:expressconnect/trafficQos:TrafficQos example <id>
        ```

        :param str resource_name: The name of the resource.
        :param TrafficQosArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TrafficQosArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 qos_description: Optional[pulumi.Input[str]] = None,
                 qos_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TrafficQosArgs.__new__(TrafficQosArgs)

            __props__.__dict__["qos_description"] = qos_description
            __props__.__dict__["qos_name"] = qos_name
            __props__.__dict__["status"] = None
        super(TrafficQos, __self__).__init__(
            'alicloud:expressconnect/trafficQos:TrafficQos',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            qos_description: Optional[pulumi.Input[str]] = None,
            qos_name: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None) -> 'TrafficQos':
        """
        Get an existing TrafficQos resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] qos_description: The description of the QoS policy.  The length is **0** to **256** characters and cannot start with 'http:// 'or 'https.
        :param pulumi.Input[str] qos_name: The name of the QoS policy.  The length is **0** to **128** characters and cannot start with 'http:// 'or 'https.
        :param pulumi.Input[str] status: The status of the QoS policy. Value:
               > **NOTE:**  QoS in the configuration state will restrict the creation, update, and deletion of most QoS policies, QoS queues, and QoS rules.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TrafficQosState.__new__(_TrafficQosState)

        __props__.__dict__["qos_description"] = qos_description
        __props__.__dict__["qos_name"] = qos_name
        __props__.__dict__["status"] = status
        return TrafficQos(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="qosDescription")
    def qos_description(self) -> pulumi.Output[Optional[str]]:
        """
        The description of the QoS policy.  The length is **0** to **256** characters and cannot start with 'http:// 'or 'https.
        """
        return pulumi.get(self, "qos_description")

    @property
    @pulumi.getter(name="qosName")
    def qos_name(self) -> pulumi.Output[Optional[str]]:
        """
        The name of the QoS policy.  The length is **0** to **128** characters and cannot start with 'http:// 'or 'https.
        """
        return pulumi.get(self, "qos_name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the QoS policy. Value:
        > **NOTE:**  QoS in the configuration state will restrict the creation, update, and deletion of most QoS policies, QoS queues, and QoS rules.
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ClientFileProtectArgs', 'ClientFileProtect']

@pulumi.input_type
class ClientFileProtectArgs:
    def __init__(__self__, *,
                 file_ops: pulumi.Input[Sequence[pulumi.Input[str]]],
                 file_paths: pulumi.Input[Sequence[pulumi.Input[str]]],
                 proc_paths: pulumi.Input[Sequence[pulumi.Input[str]]],
                 rule_action: pulumi.Input[str],
                 rule_name: pulumi.Input[str],
                 alert_level: Optional[pulumi.Input[int]] = None,
                 status: Optional[pulumi.Input[int]] = None,
                 switch_id: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a ClientFileProtect resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] file_ops: file operation.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] file_paths: file path.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] proc_paths: process path.
        :param pulumi.Input[str] rule_action: rule action, pass or alert.
        :param pulumi.Input[str] rule_name: ruleName.
        :param pulumi.Input[int] alert_level: 0 no alert 1 info 2 suspicious 3 critical.
        :param pulumi.Input[int] status: rule status 0 is disable 1 is enable.
        :param pulumi.Input[str] switch_id: switch id.
        """
        pulumi.set(__self__, "file_ops", file_ops)
        pulumi.set(__self__, "file_paths", file_paths)
        pulumi.set(__self__, "proc_paths", proc_paths)
        pulumi.set(__self__, "rule_action", rule_action)
        pulumi.set(__self__, "rule_name", rule_name)
        if alert_level is not None:
            pulumi.set(__self__, "alert_level", alert_level)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if switch_id is not None:
            pulumi.set(__self__, "switch_id", switch_id)

    @property
    @pulumi.getter(name="fileOps")
    def file_ops(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        file operation.
        """
        return pulumi.get(self, "file_ops")

    @file_ops.setter
    def file_ops(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "file_ops", value)

    @property
    @pulumi.getter(name="filePaths")
    def file_paths(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        file path.
        """
        return pulumi.get(self, "file_paths")

    @file_paths.setter
    def file_paths(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "file_paths", value)

    @property
    @pulumi.getter(name="procPaths")
    def proc_paths(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        process path.
        """
        return pulumi.get(self, "proc_paths")

    @proc_paths.setter
    def proc_paths(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "proc_paths", value)

    @property
    @pulumi.getter(name="ruleAction")
    def rule_action(self) -> pulumi.Input[str]:
        """
        rule action, pass or alert.
        """
        return pulumi.get(self, "rule_action")

    @rule_action.setter
    def rule_action(self, value: pulumi.Input[str]):
        pulumi.set(self, "rule_action", value)

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> pulumi.Input[str]:
        """
        ruleName.
        """
        return pulumi.get(self, "rule_name")

    @rule_name.setter
    def rule_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "rule_name", value)

    @property
    @pulumi.getter(name="alertLevel")
    def alert_level(self) -> Optional[pulumi.Input[int]]:
        """
        0 no alert 1 info 2 suspicious 3 critical.
        """
        return pulumi.get(self, "alert_level")

    @alert_level.setter
    def alert_level(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "alert_level", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[int]]:
        """
        rule status 0 is disable 1 is enable.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="switchId")
    def switch_id(self) -> Optional[pulumi.Input[str]]:
        """
        switch id.
        """
        return pulumi.get(self, "switch_id")

    @switch_id.setter
    def switch_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "switch_id", value)


@pulumi.input_type
class _ClientFileProtectState:
    def __init__(__self__, *,
                 alert_level: Optional[pulumi.Input[int]] = None,
                 file_ops: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 file_paths: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 proc_paths: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 rule_action: Optional[pulumi.Input[str]] = None,
                 rule_name: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[int]] = None,
                 switch_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ClientFileProtect resources.
        :param pulumi.Input[int] alert_level: 0 no alert 1 info 2 suspicious 3 critical.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] file_ops: file operation.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] file_paths: file path.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] proc_paths: process path.
        :param pulumi.Input[str] rule_action: rule action, pass or alert.
        :param pulumi.Input[str] rule_name: ruleName.
        :param pulumi.Input[int] status: rule status 0 is disable 1 is enable.
        :param pulumi.Input[str] switch_id: switch id.
        """
        if alert_level is not None:
            pulumi.set(__self__, "alert_level", alert_level)
        if file_ops is not None:
            pulumi.set(__self__, "file_ops", file_ops)
        if file_paths is not None:
            pulumi.set(__self__, "file_paths", file_paths)
        if proc_paths is not None:
            pulumi.set(__self__, "proc_paths", proc_paths)
        if rule_action is not None:
            pulumi.set(__self__, "rule_action", rule_action)
        if rule_name is not None:
            pulumi.set(__self__, "rule_name", rule_name)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if switch_id is not None:
            pulumi.set(__self__, "switch_id", switch_id)

    @property
    @pulumi.getter(name="alertLevel")
    def alert_level(self) -> Optional[pulumi.Input[int]]:
        """
        0 no alert 1 info 2 suspicious 3 critical.
        """
        return pulumi.get(self, "alert_level")

    @alert_level.setter
    def alert_level(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "alert_level", value)

    @property
    @pulumi.getter(name="fileOps")
    def file_ops(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        file operation.
        """
        return pulumi.get(self, "file_ops")

    @file_ops.setter
    def file_ops(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "file_ops", value)

    @property
    @pulumi.getter(name="filePaths")
    def file_paths(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        file path.
        """
        return pulumi.get(self, "file_paths")

    @file_paths.setter
    def file_paths(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "file_paths", value)

    @property
    @pulumi.getter(name="procPaths")
    def proc_paths(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        process path.
        """
        return pulumi.get(self, "proc_paths")

    @proc_paths.setter
    def proc_paths(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "proc_paths", value)

    @property
    @pulumi.getter(name="ruleAction")
    def rule_action(self) -> Optional[pulumi.Input[str]]:
        """
        rule action, pass or alert.
        """
        return pulumi.get(self, "rule_action")

    @rule_action.setter
    def rule_action(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "rule_action", value)

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> Optional[pulumi.Input[str]]:
        """
        ruleName.
        """
        return pulumi.get(self, "rule_name")

    @rule_name.setter
    def rule_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "rule_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[int]]:
        """
        rule status 0 is disable 1 is enable.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="switchId")
    def switch_id(self) -> Optional[pulumi.Input[str]]:
        """
        switch id.
        """
        return pulumi.get(self, "switch_id")

    @switch_id.setter
    def switch_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "switch_id", value)


class ClientFileProtect(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 alert_level: Optional[pulumi.Input[int]] = None,
                 file_ops: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 file_paths: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 proc_paths: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 rule_action: Optional[pulumi.Input[str]] = None,
                 rule_name: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[int]] = None,
                 switch_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Threat Detection Client File Protect resource. Client core file protection event monitoring, including file reading and writing, deletion, and permission change.

        For information about Threat Detection Client File Protect and how to use it, see [What is Client File Protect](https://www.alibabacloud.com/help/zh/security-center/developer-reference/api-sas-2018-12-03-createfileprotectrule).

        > **NOTE:** Available since v1.212.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.threatdetection.ClientFileProtect("default",
            status=0,
            file_paths=["/usr/local"],
            file_ops=["CREATE"],
            rule_action="pass",
            proc_paths=["/usr/local"],
            alert_level=0,
            switch_id="FILE_PROTECT_RULE_SWITCH_TYPE_1693474122929",
            rule_name="rule_example")
        ```

        ## Import

        Threat Detection Client File Protect can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:threatdetection/clientFileProtect:ClientFileProtect example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] alert_level: 0 no alert 1 info 2 suspicious 3 critical.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] file_ops: file operation.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] file_paths: file path.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] proc_paths: process path.
        :param pulumi.Input[str] rule_action: rule action, pass or alert.
        :param pulumi.Input[str] rule_name: ruleName.
        :param pulumi.Input[int] status: rule status 0 is disable 1 is enable.
        :param pulumi.Input[str] switch_id: switch id.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ClientFileProtectArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Threat Detection Client File Protect resource. Client core file protection event monitoring, including file reading and writing, deletion, and permission change.

        For information about Threat Detection Client File Protect and how to use it, see [What is Client File Protect](https://www.alibabacloud.com/help/zh/security-center/developer-reference/api-sas-2018-12-03-createfileprotectrule).

        > **NOTE:** Available since v1.212.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.threatdetection.ClientFileProtect("default",
            status=0,
            file_paths=["/usr/local"],
            file_ops=["CREATE"],
            rule_action="pass",
            proc_paths=["/usr/local"],
            alert_level=0,
            switch_id="FILE_PROTECT_RULE_SWITCH_TYPE_1693474122929",
            rule_name="rule_example")
        ```

        ## Import

        Threat Detection Client File Protect can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:threatdetection/clientFileProtect:ClientFileProtect example <id>
        ```

        :param str resource_name: The name of the resource.
        :param ClientFileProtectArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ClientFileProtectArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 alert_level: Optional[pulumi.Input[int]] = None,
                 file_ops: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 file_paths: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 proc_paths: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 rule_action: Optional[pulumi.Input[str]] = None,
                 rule_name: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[int]] = None,
                 switch_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ClientFileProtectArgs.__new__(ClientFileProtectArgs)

            __props__.__dict__["alert_level"] = alert_level
            if file_ops is None and not opts.urn:
                raise TypeError("Missing required property 'file_ops'")
            __props__.__dict__["file_ops"] = file_ops
            if file_paths is None and not opts.urn:
                raise TypeError("Missing required property 'file_paths'")
            __props__.__dict__["file_paths"] = file_paths
            if proc_paths is None and not opts.urn:
                raise TypeError("Missing required property 'proc_paths'")
            __props__.__dict__["proc_paths"] = proc_paths
            if rule_action is None and not opts.urn:
                raise TypeError("Missing required property 'rule_action'")
            __props__.__dict__["rule_action"] = rule_action
            if rule_name is None and not opts.urn:
                raise TypeError("Missing required property 'rule_name'")
            __props__.__dict__["rule_name"] = rule_name
            __props__.__dict__["status"] = status
            __props__.__dict__["switch_id"] = switch_id
        super(ClientFileProtect, __self__).__init__(
            'alicloud:threatdetection/clientFileProtect:ClientFileProtect',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            alert_level: Optional[pulumi.Input[int]] = None,
            file_ops: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            file_paths: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            proc_paths: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            rule_action: Optional[pulumi.Input[str]] = None,
            rule_name: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[int]] = None,
            switch_id: Optional[pulumi.Input[str]] = None) -> 'ClientFileProtect':
        """
        Get an existing ClientFileProtect resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] alert_level: 0 no alert 1 info 2 suspicious 3 critical.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] file_ops: file operation.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] file_paths: file path.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] proc_paths: process path.
        :param pulumi.Input[str] rule_action: rule action, pass or alert.
        :param pulumi.Input[str] rule_name: ruleName.
        :param pulumi.Input[int] status: rule status 0 is disable 1 is enable.
        :param pulumi.Input[str] switch_id: switch id.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ClientFileProtectState.__new__(_ClientFileProtectState)

        __props__.__dict__["alert_level"] = alert_level
        __props__.__dict__["file_ops"] = file_ops
        __props__.__dict__["file_paths"] = file_paths
        __props__.__dict__["proc_paths"] = proc_paths
        __props__.__dict__["rule_action"] = rule_action
        __props__.__dict__["rule_name"] = rule_name
        __props__.__dict__["status"] = status
        __props__.__dict__["switch_id"] = switch_id
        return ClientFileProtect(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="alertLevel")
    def alert_level(self) -> pulumi.Output[Optional[int]]:
        """
        0 no alert 1 info 2 suspicious 3 critical.
        """
        return pulumi.get(self, "alert_level")

    @property
    @pulumi.getter(name="fileOps")
    def file_ops(self) -> pulumi.Output[Sequence[str]]:
        """
        file operation.
        """
        return pulumi.get(self, "file_ops")

    @property
    @pulumi.getter(name="filePaths")
    def file_paths(self) -> pulumi.Output[Sequence[str]]:
        """
        file path.
        """
        return pulumi.get(self, "file_paths")

    @property
    @pulumi.getter(name="procPaths")
    def proc_paths(self) -> pulumi.Output[Sequence[str]]:
        """
        process path.
        """
        return pulumi.get(self, "proc_paths")

    @property
    @pulumi.getter(name="ruleAction")
    def rule_action(self) -> pulumi.Output[str]:
        """
        rule action, pass or alert.
        """
        return pulumi.get(self, "rule_action")

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> pulumi.Output[str]:
        """
        ruleName.
        """
        return pulumi.get(self, "rule_name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[int]:
        """
        rule status 0 is disable 1 is enable.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="switchId")
    def switch_id(self) -> pulumi.Output[Optional[str]]:
        """
        switch id.
        """
        return pulumi.get(self, "switch_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'DhcpOptionsSetAssociateVpcArgs',
    'DhcpOptionsSetAssociateVpcArgsDict',
    'NetworkAclAttachmentResourceArgs',
    'NetworkAclAttachmentResourceArgsDict',
    'NetworkAclEgressAclEntryArgs',
    'NetworkAclEgressAclEntryArgsDict',
    'NetworkAclEntriesEgressArgs',
    'NetworkAclEntriesEgressArgsDict',
    'NetworkAclEntriesIngressArgs',
    'NetworkAclEntriesIngressArgsDict',
    'NetworkAclIngressAclEntryArgs',
    'NetworkAclIngressAclEntryArgsDict',
    'NetworkAclResourceArgs',
    'NetworkAclResourceArgsDict',
    'NetworkIpv6CidrBlockArgs',
    'NetworkIpv6CidrBlockArgsDict',
    'PrefixListEntryArgs',
    'PrefixListEntryArgsDict',
    'PrefixListPrefixListAssociationArgs',
    'PrefixListPrefixListAssociationArgsDict',
    'TrafficMirrorFilterEgressRuleArgs',
    'TrafficMirrorFilterEgressRuleArgsDict',
    'TrafficMirrorFilterIngressRuleArgs',
    'TrafficMirrorFilterIngressRuleArgsDict',
]

MYPY = False

if not MYPY:
    class DhcpOptionsSetAssociateVpcArgsDict(TypedDict):
        vpc_id: pulumi.Input[str]
        """
        The ID of the VPC network that is associated with the DHCP options set.
        """
        associate_status: NotRequired[pulumi.Input[str]]
        """
        The status of the VPC associated with the DHCP option set.
        """
elif False:
    DhcpOptionsSetAssociateVpcArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DhcpOptionsSetAssociateVpcArgs:
    def __init__(__self__, *,
                 vpc_id: pulumi.Input[str],
                 associate_status: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] vpc_id: The ID of the VPC network that is associated with the DHCP options set.
        :param pulumi.Input[str] associate_status: The status of the VPC associated with the DHCP option set.
        """
        pulumi.set(__self__, "vpc_id", vpc_id)
        if associate_status is not None:
            pulumi.set(__self__, "associate_status", associate_status)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Input[str]:
        """
        The ID of the VPC network that is associated with the DHCP options set.
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="associateStatus")
    def associate_status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the VPC associated with the DHCP option set.
        """
        return pulumi.get(self, "associate_status")

    @associate_status.setter
    def associate_status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "associate_status", value)


if not MYPY:
    class NetworkAclAttachmentResourceArgsDict(TypedDict):
        resource_id: pulumi.Input[str]
        """
        The resource id that the network acl will associate with.
        """
        resource_type: pulumi.Input[str]
        """
        The resource id that the network acl will associate with. Only support `VSwitch` now.
        """
elif False:
    NetworkAclAttachmentResourceArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class NetworkAclAttachmentResourceArgs:
    def __init__(__self__, *,
                 resource_id: pulumi.Input[str],
                 resource_type: pulumi.Input[str]):
        """
        :param pulumi.Input[str] resource_id: The resource id that the network acl will associate with.
        :param pulumi.Input[str] resource_type: The resource id that the network acl will associate with. Only support `VSwitch` now.
        """
        pulumi.set(__self__, "resource_id", resource_id)
        pulumi.set(__self__, "resource_type", resource_type)

    @property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> pulumi.Input[str]:
        """
        The resource id that the network acl will associate with.
        """
        return pulumi.get(self, "resource_id")

    @resource_id.setter
    def resource_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "resource_id", value)

    @property
    @pulumi.getter(name="resourceType")
    def resource_type(self) -> pulumi.Input[str]:
        """
        The resource id that the network acl will associate with. Only support `VSwitch` now.
        """
        return pulumi.get(self, "resource_type")

    @resource_type.setter
    def resource_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "resource_type", value)


if not MYPY:
    class NetworkAclEgressAclEntryArgsDict(TypedDict):
        description: NotRequired[pulumi.Input[str]]
        """
        The description of the outbound rule.  The description must be 1 to 256 characters in length and cannot start with http:// or https.
        """
        destination_cidr_ip: NotRequired[pulumi.Input[str]]
        """
        The network of the destination address.
        """
        entry_type: NotRequired[pulumi.Input[str]]
        """
        The route entry type. The value can be `custom`, indicating custom.
        """
        ip_version: NotRequired[pulumi.Input[str]]
        """
        The IP protocol version of the route entry. Valid values: "IPV4" and "IPV4'.
        """
        network_acl_entry_name: NotRequired[pulumi.Input[str]]
        """
        Name of the outbound rule entry.  The name must be 1 to 128 characters in length and cannot start with http:// or https.
        """
        policy: NotRequired[pulumi.Input[str]]
        """
        Authorization policy. Value:
        - accept: Allow.
        - drop: Refused.
        """
        port: NotRequired[pulumi.Input[str]]
        """
        The destination port range of the outbound rule.  When the Protocol type of the outbound rule is all, icmp, or gre, the port range is - 1/-1, indicating that the port is not restricted. When the Protocol type of the outbound rule is tcp or udp, the port range is 1 to 65535, and the format is 1/200 or 80/80, indicating port 1 to port 200 or port 80.
        """
        protocol: NotRequired[pulumi.Input[str]]
        """
        The protocol type. Value:
        - icmp: Network Control Message Protocol.
        - gre: Generic Routing Encapsulation Protocol.
        - tcp: Transmission Control Protocol.
        - udp: User Datagram Protocol.
        - all: Supports all protocols.
        """
elif False:
    NetworkAclEgressAclEntryArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class NetworkAclEgressAclEntryArgs:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[str]] = None,
                 destination_cidr_ip: Optional[pulumi.Input[str]] = None,
                 entry_type: Optional[pulumi.Input[str]] = None,
                 ip_version: Optional[pulumi.Input[str]] = None,
                 network_acl_entry_name: Optional[pulumi.Input[str]] = None,
                 policy: Optional[pulumi.Input[str]] = None,
                 port: Optional[pulumi.Input[str]] = None,
                 protocol: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] description: The description of the outbound rule.  The description must be 1 to 256 characters in length and cannot start with http:// or https.
        :param pulumi.Input[str] destination_cidr_ip: The network of the destination address.
        :param pulumi.Input[str] entry_type: The route entry type. The value can be `custom`, indicating custom.
        :param pulumi.Input[str] ip_version: The IP protocol version of the route entry. Valid values: "IPV4" and "IPV4'.
        :param pulumi.Input[str] network_acl_entry_name: Name of the outbound rule entry.  The name must be 1 to 128 characters in length and cannot start with http:// or https.
        :param pulumi.Input[str] policy: Authorization policy. Value:
               - accept: Allow.
               - drop: Refused.
        :param pulumi.Input[str] port: The destination port range of the outbound rule.  When the Protocol type of the outbound rule is all, icmp, or gre, the port range is - 1/-1, indicating that the port is not restricted. When the Protocol type of the outbound rule is tcp or udp, the port range is 1 to 65535, and the format is 1/200 or 80/80, indicating port 1 to port 200 or port 80.
        :param pulumi.Input[str] protocol: The protocol type. Value:
               - icmp: Network Control Message Protocol.
               - gre: Generic Routing Encapsulation Protocol.
               - tcp: Transmission Control Protocol.
               - udp: User Datagram Protocol.
               - all: Supports all protocols.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if destination_cidr_ip is not None:
            pulumi.set(__self__, "destination_cidr_ip", destination_cidr_ip)
        if entry_type is not None:
            pulumi.set(__self__, "entry_type", entry_type)
        if ip_version is not None:
            pulumi.set(__self__, "ip_version", ip_version)
        if network_acl_entry_name is not None:
            pulumi.set(__self__, "network_acl_entry_name", network_acl_entry_name)
        if policy is not None:
            pulumi.set(__self__, "policy", policy)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the outbound rule.  The description must be 1 to 256 characters in length and cannot start with http:// or https.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="destinationCidrIp")
    def destination_cidr_ip(self) -> Optional[pulumi.Input[str]]:
        """
        The network of the destination address.
        """
        return pulumi.get(self, "destination_cidr_ip")

    @destination_cidr_ip.setter
    def destination_cidr_ip(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "destination_cidr_ip", value)

    @property
    @pulumi.getter(name="entryType")
    def entry_type(self) -> Optional[pulumi.Input[str]]:
        """
        The route entry type. The value can be `custom`, indicating custom.
        """
        return pulumi.get(self, "entry_type")

    @entry_type.setter
    def entry_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "entry_type", value)

    @property
    @pulumi.getter(name="ipVersion")
    def ip_version(self) -> Optional[pulumi.Input[str]]:
        """
        The IP protocol version of the route entry. Valid values: "IPV4" and "IPV4'.
        """
        return pulumi.get(self, "ip_version")

    @ip_version.setter
    def ip_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ip_version", value)

    @property
    @pulumi.getter(name="networkAclEntryName")
    def network_acl_entry_name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the outbound rule entry.  The name must be 1 to 128 characters in length and cannot start with http:// or https.
        """
        return pulumi.get(self, "network_acl_entry_name")

    @network_acl_entry_name.setter
    def network_acl_entry_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "network_acl_entry_name", value)

    @property
    @pulumi.getter
    def policy(self) -> Optional[pulumi.Input[str]]:
        """
        Authorization policy. Value:
        - accept: Allow.
        - drop: Refused.
        """
        return pulumi.get(self, "policy")

    @policy.setter
    def policy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "policy", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[str]]:
        """
        The destination port range of the outbound rule.  When the Protocol type of the outbound rule is all, icmp, or gre, the port range is - 1/-1, indicating that the port is not restricted. When the Protocol type of the outbound rule is tcp or udp, the port range is 1 to 65535, and the format is 1/200 or 80/80, indicating port 1 to port 200 or port 80.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[str]]:
        """
        The protocol type. Value:
        - icmp: Network Control Message Protocol.
        - gre: Generic Routing Encapsulation Protocol.
        - tcp: Transmission Control Protocol.
        - udp: User Datagram Protocol.
        - all: Supports all protocols.
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "protocol", value)


if not MYPY:
    class NetworkAclEntriesEgressArgsDict(TypedDict):
        description: NotRequired[pulumi.Input[str]]
        destination_cidr_ip: NotRequired[pulumi.Input[str]]
        """
        The destination ip of the egress entry.
        """
        entry_type: NotRequired[pulumi.Input[str]]
        name: NotRequired[pulumi.Input[str]]
        policy: NotRequired[pulumi.Input[str]]
        port: NotRequired[pulumi.Input[str]]
        protocol: NotRequired[pulumi.Input[str]]
elif False:
    NetworkAclEntriesEgressArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class NetworkAclEntriesEgressArgs:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[str]] = None,
                 destination_cidr_ip: Optional[pulumi.Input[str]] = None,
                 entry_type: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 policy: Optional[pulumi.Input[str]] = None,
                 port: Optional[pulumi.Input[str]] = None,
                 protocol: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] destination_cidr_ip: The destination ip of the egress entry.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if destination_cidr_ip is not None:
            pulumi.set(__self__, "destination_cidr_ip", destination_cidr_ip)
        if entry_type is not None:
            pulumi.set(__self__, "entry_type", entry_type)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if policy is not None:
            pulumi.set(__self__, "policy", policy)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="destinationCidrIp")
    def destination_cidr_ip(self) -> Optional[pulumi.Input[str]]:
        """
        The destination ip of the egress entry.
        """
        return pulumi.get(self, "destination_cidr_ip")

    @destination_cidr_ip.setter
    def destination_cidr_ip(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "destination_cidr_ip", value)

    @property
    @pulumi.getter(name="entryType")
    def entry_type(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "entry_type")

    @entry_type.setter
    def entry_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "entry_type", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def policy(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "policy")

    @policy.setter
    def policy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "policy", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "protocol", value)


if not MYPY:
    class NetworkAclEntriesIngressArgsDict(TypedDict):
        description: NotRequired[pulumi.Input[str]]
        entry_type: NotRequired[pulumi.Input[str]]
        name: NotRequired[pulumi.Input[str]]
        policy: NotRequired[pulumi.Input[str]]
        port: NotRequired[pulumi.Input[str]]
        protocol: NotRequired[pulumi.Input[str]]
        source_cidr_ip: NotRequired[pulumi.Input[str]]
        """
        The source ip of the ingress entry.
        """
elif False:
    NetworkAclEntriesIngressArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class NetworkAclEntriesIngressArgs:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[str]] = None,
                 entry_type: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 policy: Optional[pulumi.Input[str]] = None,
                 port: Optional[pulumi.Input[str]] = None,
                 protocol: Optional[pulumi.Input[str]] = None,
                 source_cidr_ip: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] source_cidr_ip: The source ip of the ingress entry.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if entry_type is not None:
            pulumi.set(__self__, "entry_type", entry_type)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if policy is not None:
            pulumi.set(__self__, "policy", policy)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if source_cidr_ip is not None:
            pulumi.set(__self__, "source_cidr_ip", source_cidr_ip)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="entryType")
    def entry_type(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "entry_type")

    @entry_type.setter
    def entry_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "entry_type", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def policy(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "policy")

    @policy.setter
    def policy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "policy", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter(name="sourceCidrIp")
    def source_cidr_ip(self) -> Optional[pulumi.Input[str]]:
        """
        The source ip of the ingress entry.
        """
        return pulumi.get(self, "source_cidr_ip")

    @source_cidr_ip.setter
    def source_cidr_ip(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_cidr_ip", value)


if not MYPY:
    class NetworkAclIngressAclEntryArgsDict(TypedDict):
        description: NotRequired[pulumi.Input[str]]
        """
        Description of the inbound rule.  The description must be 1 to 256 characters in length and cannot start with http:// or https.
        """
        entry_type: NotRequired[pulumi.Input[str]]
        """
        The route entry type. The value can be `custom`, indicating custom.
        """
        ip_version: NotRequired[pulumi.Input[str]]
        """
        The IP protocol version of the route entry. Valid values: "IPV4" and "IPV6'.
        """
        network_acl_entry_name: NotRequired[pulumi.Input[str]]
        """
        The name of the inbound rule entry.  The name must be 1 to 128 characters in length and cannot start with http:// or https.
        """
        policy: NotRequired[pulumi.Input[str]]
        """
        Authorization policy. Value:
        - accept: Allow.
        - drop: Refused.
        """
        port: NotRequired[pulumi.Input[str]]
        """
        The source port range of the inbound rule.  When the Protocol type of the inbound rule is all, icmp, or gre, the port range is - 1/-1, indicating that the port is not restricted. When the Protocol type of the inbound rule is tcp or udp, the port range is 1 to 65535, and the format is 1/200 or 80/80, indicating port 1 to port 200 or port 80.
        """
        protocol: NotRequired[pulumi.Input[str]]
        """
        The protocol type. Value:
        - icmp: Network Control Message Protocol.
        - gre: Generic Routing Encapsulation Protocol.
        - tcp: Transmission Control Protocol.
        - udp: User Datagram Protocol.
        - all: Supports all protocols.
        """
        source_cidr_ip: NotRequired[pulumi.Input[str]]
        """
        Source address network segment.
        """
elif False:
    NetworkAclIngressAclEntryArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class NetworkAclIngressAclEntryArgs:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[str]] = None,
                 entry_type: Optional[pulumi.Input[str]] = None,
                 ip_version: Optional[pulumi.Input[str]] = None,
                 network_acl_entry_name: Optional[pulumi.Input[str]] = None,
                 policy: Optional[pulumi.Input[str]] = None,
                 port: Optional[pulumi.Input[str]] = None,
                 protocol: Optional[pulumi.Input[str]] = None,
                 source_cidr_ip: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] description: Description of the inbound rule.  The description must be 1 to 256 characters in length and cannot start with http:// or https.
        :param pulumi.Input[str] entry_type: The route entry type. The value can be `custom`, indicating custom.
        :param pulumi.Input[str] ip_version: The IP protocol version of the route entry. Valid values: "IPV4" and "IPV6'.
        :param pulumi.Input[str] network_acl_entry_name: The name of the inbound rule entry.  The name must be 1 to 128 characters in length and cannot start with http:// or https.
        :param pulumi.Input[str] policy: Authorization policy. Value:
               - accept: Allow.
               - drop: Refused.
        :param pulumi.Input[str] port: The source port range of the inbound rule.  When the Protocol type of the inbound rule is all, icmp, or gre, the port range is - 1/-1, indicating that the port is not restricted. When the Protocol type of the inbound rule is tcp or udp, the port range is 1 to 65535, and the format is 1/200 or 80/80, indicating port 1 to port 200 or port 80.
        :param pulumi.Input[str] protocol: The protocol type. Value:
               - icmp: Network Control Message Protocol.
               - gre: Generic Routing Encapsulation Protocol.
               - tcp: Transmission Control Protocol.
               - udp: User Datagram Protocol.
               - all: Supports all protocols.
        :param pulumi.Input[str] source_cidr_ip: Source address network segment.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if entry_type is not None:
            pulumi.set(__self__, "entry_type", entry_type)
        if ip_version is not None:
            pulumi.set(__self__, "ip_version", ip_version)
        if network_acl_entry_name is not None:
            pulumi.set(__self__, "network_acl_entry_name", network_acl_entry_name)
        if policy is not None:
            pulumi.set(__self__, "policy", policy)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if source_cidr_ip is not None:
            pulumi.set(__self__, "source_cidr_ip", source_cidr_ip)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description of the inbound rule.  The description must be 1 to 256 characters in length and cannot start with http:// or https.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="entryType")
    def entry_type(self) -> Optional[pulumi.Input[str]]:
        """
        The route entry type. The value can be `custom`, indicating custom.
        """
        return pulumi.get(self, "entry_type")

    @entry_type.setter
    def entry_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "entry_type", value)

    @property
    @pulumi.getter(name="ipVersion")
    def ip_version(self) -> Optional[pulumi.Input[str]]:
        """
        The IP protocol version of the route entry. Valid values: "IPV4" and "IPV6'.
        """
        return pulumi.get(self, "ip_version")

    @ip_version.setter
    def ip_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ip_version", value)

    @property
    @pulumi.getter(name="networkAclEntryName")
    def network_acl_entry_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the inbound rule entry.  The name must be 1 to 128 characters in length and cannot start with http:// or https.
        """
        return pulumi.get(self, "network_acl_entry_name")

    @network_acl_entry_name.setter
    def network_acl_entry_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "network_acl_entry_name", value)

    @property
    @pulumi.getter
    def policy(self) -> Optional[pulumi.Input[str]]:
        """
        Authorization policy. Value:
        - accept: Allow.
        - drop: Refused.
        """
        return pulumi.get(self, "policy")

    @policy.setter
    def policy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "policy", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[str]]:
        """
        The source port range of the inbound rule.  When the Protocol type of the inbound rule is all, icmp, or gre, the port range is - 1/-1, indicating that the port is not restricted. When the Protocol type of the inbound rule is tcp or udp, the port range is 1 to 65535, and the format is 1/200 or 80/80, indicating port 1 to port 200 or port 80.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[str]]:
        """
        The protocol type. Value:
        - icmp: Network Control Message Protocol.
        - gre: Generic Routing Encapsulation Protocol.
        - tcp: Transmission Control Protocol.
        - udp: User Datagram Protocol.
        - all: Supports all protocols.
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter(name="sourceCidrIp")
    def source_cidr_ip(self) -> Optional[pulumi.Input[str]]:
        """
        Source address network segment.
        """
        return pulumi.get(self, "source_cidr_ip")

    @source_cidr_ip.setter
    def source_cidr_ip(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_cidr_ip", value)


if not MYPY:
    class NetworkAclResourceArgsDict(TypedDict):
        resource_id: pulumi.Input[str]
        """
        The ID of the associated resource.
        """
        resource_type: pulumi.Input[str]
        """
        The type of the associated resource.
        """
        status: NotRequired[pulumi.Input[str]]
        """
        The state of the network ACL.
        """
elif False:
    NetworkAclResourceArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class NetworkAclResourceArgs:
    def __init__(__self__, *,
                 resource_id: pulumi.Input[str],
                 resource_type: pulumi.Input[str],
                 status: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] resource_id: The ID of the associated resource.
        :param pulumi.Input[str] resource_type: The type of the associated resource.
        :param pulumi.Input[str] status: The state of the network ACL.
        """
        pulumi.set(__self__, "resource_id", resource_id)
        pulumi.set(__self__, "resource_type", resource_type)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> pulumi.Input[str]:
        """
        The ID of the associated resource.
        """
        return pulumi.get(self, "resource_id")

    @resource_id.setter
    def resource_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "resource_id", value)

    @property
    @pulumi.getter(name="resourceType")
    def resource_type(self) -> pulumi.Input[str]:
        """
        The type of the associated resource.
        """
        return pulumi.get(self, "resource_type")

    @resource_type.setter
    def resource_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "resource_type", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The state of the network ACL.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


if not MYPY:
    class NetworkIpv6CidrBlockArgsDict(TypedDict):
        ipv6_cidr_block: NotRequired[pulumi.Input[str]]
        """
        The IPv6 CIDR block of the default VPC.

        > **NOTE:**  When `EnableIpv6` is set to `true`, this parameter is required.
        """
        ipv6_isp: NotRequired[pulumi.Input[str]]
        """
        The IPv6 address segment type of the VPC. Value:
        - `BGP` (default): Alibaba Cloud BGP IPv6.
        - `ChinaMobile`: China Mobile (single line).
        - `ChinaUnicom`: China Unicom (single line).
        - `ChinaTelecom`: China Telecom (single line).

        > **NOTE:**  If a single-line bandwidth whitelist is enabled, this field can be set to `ChinaTelecom` (China Telecom), `ChinaUnicom` (China Unicom), or `ChinaMobile` (China Mobile).
        """
elif False:
    NetworkIpv6CidrBlockArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class NetworkIpv6CidrBlockArgs:
    def __init__(__self__, *,
                 ipv6_cidr_block: Optional[pulumi.Input[str]] = None,
                 ipv6_isp: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] ipv6_cidr_block: The IPv6 CIDR block of the default VPC.
               
               > **NOTE:**  When `EnableIpv6` is set to `true`, this parameter is required.
        :param pulumi.Input[str] ipv6_isp: The IPv6 address segment type of the VPC. Value:
               - `BGP` (default): Alibaba Cloud BGP IPv6.
               - `ChinaMobile`: China Mobile (single line).
               - `ChinaUnicom`: China Unicom (single line).
               - `ChinaTelecom`: China Telecom (single line).
               
               > **NOTE:**  If a single-line bandwidth whitelist is enabled, this field can be set to `ChinaTelecom` (China Telecom), `ChinaUnicom` (China Unicom), or `ChinaMobile` (China Mobile).
        """
        if ipv6_cidr_block is not None:
            pulumi.set(__self__, "ipv6_cidr_block", ipv6_cidr_block)
        if ipv6_isp is not None:
            pulumi.set(__self__, "ipv6_isp", ipv6_isp)

    @property
    @pulumi.getter(name="ipv6CidrBlock")
    def ipv6_cidr_block(self) -> Optional[pulumi.Input[str]]:
        """
        The IPv6 CIDR block of the default VPC.

        > **NOTE:**  When `EnableIpv6` is set to `true`, this parameter is required.
        """
        return pulumi.get(self, "ipv6_cidr_block")

    @ipv6_cidr_block.setter
    def ipv6_cidr_block(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ipv6_cidr_block", value)

    @property
    @pulumi.getter(name="ipv6Isp")
    def ipv6_isp(self) -> Optional[pulumi.Input[str]]:
        """
        The IPv6 address segment type of the VPC. Value:
        - `BGP` (default): Alibaba Cloud BGP IPv6.
        - `ChinaMobile`: China Mobile (single line).
        - `ChinaUnicom`: China Unicom (single line).
        - `ChinaTelecom`: China Telecom (single line).

        > **NOTE:**  If a single-line bandwidth whitelist is enabled, this field can be set to `ChinaTelecom` (China Telecom), `ChinaUnicom` (China Unicom), or `ChinaMobile` (China Mobile).
        """
        return pulumi.get(self, "ipv6_isp")

    @ipv6_isp.setter
    def ipv6_isp(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ipv6_isp", value)


if not MYPY:
    class PrefixListEntryArgsDict(TypedDict):
        cidr: NotRequired[pulumi.Input[str]]
        """
        The CIDR address block of the prefix list.
        """
        description: NotRequired[pulumi.Input[str]]
        """
        The description of the cidr entry. It must be 2 to 256 characters in length and must start with a letter or Chinese, but cannot start with `http://` or `https://`.
        """
elif False:
    PrefixListEntryArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class PrefixListEntryArgs:
    def __init__(__self__, *,
                 cidr: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] cidr: The CIDR address block of the prefix list.
        :param pulumi.Input[str] description: The description of the cidr entry. It must be 2 to 256 characters in length and must start with a letter or Chinese, but cannot start with `http://` or `https://`.
        """
        if cidr is not None:
            pulumi.set(__self__, "cidr", cidr)
        if description is not None:
            pulumi.set(__self__, "description", description)

    @property
    @pulumi.getter
    def cidr(self) -> Optional[pulumi.Input[str]]:
        """
        The CIDR address block of the prefix list.
        """
        return pulumi.get(self, "cidr")

    @cidr.setter
    def cidr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cidr", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the cidr entry. It must be 2 to 256 characters in length and must start with a letter or Chinese, but cannot start with `http://` or `https://`.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)


if not MYPY:
    class PrefixListPrefixListAssociationArgsDict(TypedDict):
        owner_id: NotRequired[pulumi.Input[str]]
        """
        The ID of the Alibaba Cloud account (primary account) to which the prefix list belongs.
        """
        prefix_list_id: NotRequired[pulumi.Input[str]]
        """
        The ID of the query Prefix List.
        """
        reason: NotRequired[pulumi.Input[str]]
        """
        Reason when the association fails.
        """
        region_id: NotRequired[pulumi.Input[str]]
        """
        The region ID of the prefix list to be queried.
        """
        resource_id: NotRequired[pulumi.Input[str]]
        """
        The ID of the associated resource.
        """
        resource_type: NotRequired[pulumi.Input[str]]
        """
        The associated resource type. Value:-**vpcRouteTable**: The VPC route table.-**trRouteTable**: the routing table of the forwarding router.
        """
        resource_uid: NotRequired[pulumi.Input[str]]
        """
        The ID of the Alibaba Cloud account (primary account) to which the resource bound to the prefix list belongs.
        """
        status: NotRequired[pulumi.Input[str]]
        """
        Resource attribute fields that represent the status of the resource.
        """
elif False:
    PrefixListPrefixListAssociationArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class PrefixListPrefixListAssociationArgs:
    def __init__(__self__, *,
                 owner_id: Optional[pulumi.Input[str]] = None,
                 prefix_list_id: Optional[pulumi.Input[str]] = None,
                 reason: Optional[pulumi.Input[str]] = None,
                 region_id: Optional[pulumi.Input[str]] = None,
                 resource_id: Optional[pulumi.Input[str]] = None,
                 resource_type: Optional[pulumi.Input[str]] = None,
                 resource_uid: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] owner_id: The ID of the Alibaba Cloud account (primary account) to which the prefix list belongs.
        :param pulumi.Input[str] prefix_list_id: The ID of the query Prefix List.
        :param pulumi.Input[str] reason: Reason when the association fails.
        :param pulumi.Input[str] region_id: The region ID of the prefix list to be queried.
        :param pulumi.Input[str] resource_id: The ID of the associated resource.
        :param pulumi.Input[str] resource_type: The associated resource type. Value:-**vpcRouteTable**: The VPC route table.-**trRouteTable**: the routing table of the forwarding router.
        :param pulumi.Input[str] resource_uid: The ID of the Alibaba Cloud account (primary account) to which the resource bound to the prefix list belongs.
        :param pulumi.Input[str] status: Resource attribute fields that represent the status of the resource.
        """
        if owner_id is not None:
            pulumi.set(__self__, "owner_id", owner_id)
        if prefix_list_id is not None:
            pulumi.set(__self__, "prefix_list_id", prefix_list_id)
        if reason is not None:
            pulumi.set(__self__, "reason", reason)
        if region_id is not None:
            pulumi.set(__self__, "region_id", region_id)
        if resource_id is not None:
            pulumi.set(__self__, "resource_id", resource_id)
        if resource_type is not None:
            pulumi.set(__self__, "resource_type", resource_type)
        if resource_uid is not None:
            pulumi.set(__self__, "resource_uid", resource_uid)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="ownerId")
    def owner_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Alibaba Cloud account (primary account) to which the prefix list belongs.
        """
        return pulumi.get(self, "owner_id")

    @owner_id.setter
    def owner_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "owner_id", value)

    @property
    @pulumi.getter(name="prefixListId")
    def prefix_list_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the query Prefix List.
        """
        return pulumi.get(self, "prefix_list_id")

    @prefix_list_id.setter
    def prefix_list_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "prefix_list_id", value)

    @property
    @pulumi.getter
    def reason(self) -> Optional[pulumi.Input[str]]:
        """
        Reason when the association fails.
        """
        return pulumi.get(self, "reason")

    @reason.setter
    def reason(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "reason", value)

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> Optional[pulumi.Input[str]]:
        """
        The region ID of the prefix list to be queried.
        """
        return pulumi.get(self, "region_id")

    @region_id.setter
    def region_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region_id", value)

    @property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the associated resource.
        """
        return pulumi.get(self, "resource_id")

    @resource_id.setter
    def resource_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_id", value)

    @property
    @pulumi.getter(name="resourceType")
    def resource_type(self) -> Optional[pulumi.Input[str]]:
        """
        The associated resource type. Value:-**vpcRouteTable**: The VPC route table.-**trRouteTable**: the routing table of the forwarding router.
        """
        return pulumi.get(self, "resource_type")

    @resource_type.setter
    def resource_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_type", value)

    @property
    @pulumi.getter(name="resourceUid")
    def resource_uid(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Alibaba Cloud account (primary account) to which the resource bound to the prefix list belongs.
        """
        return pulumi.get(self, "resource_uid")

    @resource_uid.setter
    def resource_uid(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_uid", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        Resource attribute fields that represent the status of the resource.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


if not MYPY:
    class TrafficMirrorFilterEgressRuleArgsDict(TypedDict):
        action: pulumi.Input[str]
        protocol: pulumi.Input[str]
        destination_cidr_block: NotRequired[pulumi.Input[str]]
        destination_port_range: NotRequired[pulumi.Input[str]]
        priority: NotRequired[pulumi.Input[int]]
        source_cidr_block: NotRequired[pulumi.Input[str]]
        source_port_range: NotRequired[pulumi.Input[str]]
        traffic_mirror_filter_rule_status: NotRequired[pulumi.Input[str]]
elif False:
    TrafficMirrorFilterEgressRuleArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class TrafficMirrorFilterEgressRuleArgs:
    def __init__(__self__, *,
                 action: pulumi.Input[str],
                 protocol: pulumi.Input[str],
                 destination_cidr_block: Optional[pulumi.Input[str]] = None,
                 destination_port_range: Optional[pulumi.Input[str]] = None,
                 priority: Optional[pulumi.Input[int]] = None,
                 source_cidr_block: Optional[pulumi.Input[str]] = None,
                 source_port_range: Optional[pulumi.Input[str]] = None,
                 traffic_mirror_filter_rule_status: Optional[pulumi.Input[str]] = None):
        pulumi.set(__self__, "action", action)
        pulumi.set(__self__, "protocol", protocol)
        if destination_cidr_block is not None:
            pulumi.set(__self__, "destination_cidr_block", destination_cidr_block)
        if destination_port_range is not None:
            pulumi.set(__self__, "destination_port_range", destination_port_range)
        if priority is not None:
            pulumi.set(__self__, "priority", priority)
        if source_cidr_block is not None:
            pulumi.set(__self__, "source_cidr_block", source_cidr_block)
        if source_port_range is not None:
            pulumi.set(__self__, "source_port_range", source_port_range)
        if traffic_mirror_filter_rule_status is not None:
            pulumi.set(__self__, "traffic_mirror_filter_rule_status", traffic_mirror_filter_rule_status)

    @property
    @pulumi.getter
    def action(self) -> pulumi.Input[str]:
        return pulumi.get(self, "action")

    @action.setter
    def action(self, value: pulumi.Input[str]):
        pulumi.set(self, "action", value)

    @property
    @pulumi.getter
    def protocol(self) -> pulumi.Input[str]:
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: pulumi.Input[str]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter(name="destinationCidrBlock")
    def destination_cidr_block(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "destination_cidr_block")

    @destination_cidr_block.setter
    def destination_cidr_block(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "destination_cidr_block", value)

    @property
    @pulumi.getter(name="destinationPortRange")
    def destination_port_range(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "destination_port_range")

    @destination_port_range.setter
    def destination_port_range(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "destination_port_range", value)

    @property
    @pulumi.getter
    def priority(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "priority")

    @priority.setter
    def priority(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "priority", value)

    @property
    @pulumi.getter(name="sourceCidrBlock")
    def source_cidr_block(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "source_cidr_block")

    @source_cidr_block.setter
    def source_cidr_block(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_cidr_block", value)

    @property
    @pulumi.getter(name="sourcePortRange")
    def source_port_range(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "source_port_range")

    @source_port_range.setter
    def source_port_range(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_port_range", value)

    @property
    @pulumi.getter(name="trafficMirrorFilterRuleStatus")
    def traffic_mirror_filter_rule_status(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "traffic_mirror_filter_rule_status")

    @traffic_mirror_filter_rule_status.setter
    def traffic_mirror_filter_rule_status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "traffic_mirror_filter_rule_status", value)


if not MYPY:
    class TrafficMirrorFilterIngressRuleArgsDict(TypedDict):
        action: pulumi.Input[str]
        protocol: pulumi.Input[str]
        destination_cidr_block: NotRequired[pulumi.Input[str]]
        destination_port_range: NotRequired[pulumi.Input[str]]
        priority: NotRequired[pulumi.Input[int]]
        source_cidr_block: NotRequired[pulumi.Input[str]]
        source_port_range: NotRequired[pulumi.Input[str]]
        traffic_mirror_filter_rule_status: NotRequired[pulumi.Input[str]]
elif False:
    TrafficMirrorFilterIngressRuleArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class TrafficMirrorFilterIngressRuleArgs:
    def __init__(__self__, *,
                 action: pulumi.Input[str],
                 protocol: pulumi.Input[str],
                 destination_cidr_block: Optional[pulumi.Input[str]] = None,
                 destination_port_range: Optional[pulumi.Input[str]] = None,
                 priority: Optional[pulumi.Input[int]] = None,
                 source_cidr_block: Optional[pulumi.Input[str]] = None,
                 source_port_range: Optional[pulumi.Input[str]] = None,
                 traffic_mirror_filter_rule_status: Optional[pulumi.Input[str]] = None):
        pulumi.set(__self__, "action", action)
        pulumi.set(__self__, "protocol", protocol)
        if destination_cidr_block is not None:
            pulumi.set(__self__, "destination_cidr_block", destination_cidr_block)
        if destination_port_range is not None:
            pulumi.set(__self__, "destination_port_range", destination_port_range)
        if priority is not None:
            pulumi.set(__self__, "priority", priority)
        if source_cidr_block is not None:
            pulumi.set(__self__, "source_cidr_block", source_cidr_block)
        if source_port_range is not None:
            pulumi.set(__self__, "source_port_range", source_port_range)
        if traffic_mirror_filter_rule_status is not None:
            pulumi.set(__self__, "traffic_mirror_filter_rule_status", traffic_mirror_filter_rule_status)

    @property
    @pulumi.getter
    def action(self) -> pulumi.Input[str]:
        return pulumi.get(self, "action")

    @action.setter
    def action(self, value: pulumi.Input[str]):
        pulumi.set(self, "action", value)

    @property
    @pulumi.getter
    def protocol(self) -> pulumi.Input[str]:
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: pulumi.Input[str]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter(name="destinationCidrBlock")
    def destination_cidr_block(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "destination_cidr_block")

    @destination_cidr_block.setter
    def destination_cidr_block(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "destination_cidr_block", value)

    @property
    @pulumi.getter(name="destinationPortRange")
    def destination_port_range(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "destination_port_range")

    @destination_port_range.setter
    def destination_port_range(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "destination_port_range", value)

    @property
    @pulumi.getter
    def priority(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "priority")

    @priority.setter
    def priority(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "priority", value)

    @property
    @pulumi.getter(name="sourceCidrBlock")
    def source_cidr_block(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "source_cidr_block")

    @source_cidr_block.setter
    def source_cidr_block(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_cidr_block", value)

    @property
    @pulumi.getter(name="sourcePortRange")
    def source_port_range(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "source_port_range")

    @source_port_range.setter
    def source_port_range(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_port_range", value)

    @property
    @pulumi.getter(name="trafficMirrorFilterRuleStatus")
    def traffic_mirror_filter_rule_status(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "traffic_mirror_filter_rule_status")

    @traffic_mirror_filter_rule_status.setter
    def traffic_mirror_filter_rule_status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "traffic_mirror_filter_rule_status", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['UserArgs', 'User']

@pulumi.input_type
class UserArgs:
    def __init__(__self__, *,
                 email: pulumi.Input[str],
                 end_user_id: pulumi.Input[str],
                 password: Optional[pulumi.Input[str]] = None,
                 phone: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a User resource.
        :param pulumi.Input[str] email: The email of the user email.
        :param pulumi.Input[str] end_user_id: The Username. The custom setting is composed of lowercase letters, numbers and underscores, and the length is 3~24 characters.
        :param pulumi.Input[str] password: The password of the user password.
        :param pulumi.Input[str] phone: The phone of the mobile phone number.
        :param pulumi.Input[str] status: The status of the resource. Valid values: `Unlocked`, `Locked`.
        """
        pulumi.set(__self__, "email", email)
        pulumi.set(__self__, "end_user_id", end_user_id)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if phone is not None:
            pulumi.set(__self__, "phone", phone)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def email(self) -> pulumi.Input[str]:
        """
        The email of the user email.
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: pulumi.Input[str]):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter(name="endUserId")
    def end_user_id(self) -> pulumi.Input[str]:
        """
        The Username. The custom setting is composed of lowercase letters, numbers and underscores, and the length is 3~24 characters.
        """
        return pulumi.get(self, "end_user_id")

    @end_user_id.setter
    def end_user_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "end_user_id", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[str]]:
        """
        The password of the user password.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter
    def phone(self) -> Optional[pulumi.Input[str]]:
        """
        The phone of the mobile phone number.
        """
        return pulumi.get(self, "phone")

    @phone.setter
    def phone(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "phone", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the resource. Valid values: `Unlocked`, `Locked`.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


@pulumi.input_type
class _UserState:
    def __init__(__self__, *,
                 email: Optional[pulumi.Input[str]] = None,
                 end_user_id: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 phone: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering User resources.
        :param pulumi.Input[str] email: The email of the user email.
        :param pulumi.Input[str] end_user_id: The Username. The custom setting is composed of lowercase letters, numbers and underscores, and the length is 3~24 characters.
        :param pulumi.Input[str] password: The password of the user password.
        :param pulumi.Input[str] phone: The phone of the mobile phone number.
        :param pulumi.Input[str] status: The status of the resource. Valid values: `Unlocked`, `Locked`.
        """
        if email is not None:
            pulumi.set(__self__, "email", email)
        if end_user_id is not None:
            pulumi.set(__self__, "end_user_id", end_user_id)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if phone is not None:
            pulumi.set(__self__, "phone", phone)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def email(self) -> Optional[pulumi.Input[str]]:
        """
        The email of the user email.
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter(name="endUserId")
    def end_user_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Username. The custom setting is composed of lowercase letters, numbers and underscores, and the length is 3~24 characters.
        """
        return pulumi.get(self, "end_user_id")

    @end_user_id.setter
    def end_user_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "end_user_id", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[str]]:
        """
        The password of the user password.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter
    def phone(self) -> Optional[pulumi.Input[str]]:
        """
        The phone of the mobile phone number.
        """
        return pulumi.get(self, "phone")

    @phone.setter
    def phone(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "phone", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the resource. Valid values: `Unlocked`, `Locked`.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


class User(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 email: Optional[pulumi.Input[str]] = None,
                 end_user_id: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 phone: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Elastic Desktop Service (ECD) User resource.

        For information about Elastic Desktop Service (ECD) User and how to use it, see [What is User](https://www.alibabacloud.com/help/en/wuying-workspace/developer-reference/api-eds-user-2021-03-08-createusers-desktop).

        > **NOTE:** Available since v1.142.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.eds.User("default",
            end_user_id="terraform_example123",
            email="tf.example@abc.com",
            phone="18888888888",
            password="Example_123")
        ```

        ## Import

        ECD User can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:eds/user:User example <end_user_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] email: The email of the user email.
        :param pulumi.Input[str] end_user_id: The Username. The custom setting is composed of lowercase letters, numbers and underscores, and the length is 3~24 characters.
        :param pulumi.Input[str] password: The password of the user password.
        :param pulumi.Input[str] phone: The phone of the mobile phone number.
        :param pulumi.Input[str] status: The status of the resource. Valid values: `Unlocked`, `Locked`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: UserArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Elastic Desktop Service (ECD) User resource.

        For information about Elastic Desktop Service (ECD) User and how to use it, see [What is User](https://www.alibabacloud.com/help/en/wuying-workspace/developer-reference/api-eds-user-2021-03-08-createusers-desktop).

        > **NOTE:** Available since v1.142.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.eds.User("default",
            end_user_id="terraform_example123",
            email="tf.example@abc.com",
            phone="18888888888",
            password="Example_123")
        ```

        ## Import

        ECD User can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:eds/user:User example <end_user_id>
        ```

        :param str resource_name: The name of the resource.
        :param UserArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UserArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 email: Optional[pulumi.Input[str]] = None,
                 end_user_id: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 phone: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UserArgs.__new__(UserArgs)

            if email is None and not opts.urn:
                raise TypeError("Missing required property 'email'")
            __props__.__dict__["email"] = email
            if end_user_id is None and not opts.urn:
                raise TypeError("Missing required property 'end_user_id'")
            __props__.__dict__["end_user_id"] = end_user_id
            __props__.__dict__["password"] = None if password is None else pulumi.Output.secret(password)
            __props__.__dict__["phone"] = phone
            __props__.__dict__["status"] = status
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["password"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(User, __self__).__init__(
            'alicloud:eds/user:User',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            email: Optional[pulumi.Input[str]] = None,
            end_user_id: Optional[pulumi.Input[str]] = None,
            password: Optional[pulumi.Input[str]] = None,
            phone: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None) -> 'User':
        """
        Get an existing User resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] email: The email of the user email.
        :param pulumi.Input[str] end_user_id: The Username. The custom setting is composed of lowercase letters, numbers and underscores, and the length is 3~24 characters.
        :param pulumi.Input[str] password: The password of the user password.
        :param pulumi.Input[str] phone: The phone of the mobile phone number.
        :param pulumi.Input[str] status: The status of the resource. Valid values: `Unlocked`, `Locked`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UserState.__new__(_UserState)

        __props__.__dict__["email"] = email
        __props__.__dict__["end_user_id"] = end_user_id
        __props__.__dict__["password"] = password
        __props__.__dict__["phone"] = phone
        __props__.__dict__["status"] = status
        return User(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def email(self) -> pulumi.Output[str]:
        """
        The email of the user email.
        """
        return pulumi.get(self, "email")

    @property
    @pulumi.getter(name="endUserId")
    def end_user_id(self) -> pulumi.Output[str]:
        """
        The Username. The custom setting is composed of lowercase letters, numbers and underscores, and the length is 3~24 characters.
        """
        return pulumi.get(self, "end_user_id")

    @property
    @pulumi.getter
    def password(self) -> pulumi.Output[Optional[str]]:
        """
        The password of the user password.
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter
    def phone(self) -> pulumi.Output[Optional[str]]:
        """
        The phone of the mobile phone number.
        """
        return pulumi.get(self, "phone")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the resource. Valid values: `Unlocked`, `Locked`.
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'InstanceEndpointArgs',
    'InstanceEndpointArgsDict',
]

MYPY = False

if not MYPY:
    class InstanceEndpointArgsDict(TypedDict):
        alternative_endpoints: NotRequired[pulumi.Input[str]]
        """
        Some old instances have both AnyTunnel and SingleTunnel enabled. When switching from AnyTunnel to SingleTunnel, the endpoints of both are retained. Therefore, one more field is required to store the Endpoint.
        """
        enabled: NotRequired[pulumi.Input[bool]]
        """
        Whether to turn on the network.
        """
        endpoint: NotRequired[pulumi.Input[str]]
        """
        Domain name.
        """
        type: NotRequired[pulumi.Input[str]]
        """
        The network type.
        """
        vpc_id: NotRequired[pulumi.Input[str]]
        """
        VPC primary key.
        """
        vpc_instance_id: NotRequired[pulumi.Input[str]]
        """
        The vpc instance ID.
        """
        vswitch_id: NotRequired[pulumi.Input[str]]
        """
        The ID of the virtual switch.
        """
elif False:
    InstanceEndpointArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class InstanceEndpointArgs:
    def __init__(__self__, *,
                 alternative_endpoints: Optional[pulumi.Input[str]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 endpoint: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 vpc_id: Optional[pulumi.Input[str]] = None,
                 vpc_instance_id: Optional[pulumi.Input[str]] = None,
                 vswitch_id: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] alternative_endpoints: Some old instances have both AnyTunnel and SingleTunnel enabled. When switching from AnyTunnel to SingleTunnel, the endpoints of both are retained. Therefore, one more field is required to store the Endpoint.
        :param pulumi.Input[bool] enabled: Whether to turn on the network.
        :param pulumi.Input[str] endpoint: Domain name.
        :param pulumi.Input[str] type: The network type.
        :param pulumi.Input[str] vpc_id: VPC primary key.
        :param pulumi.Input[str] vpc_instance_id: The vpc instance ID.
        :param pulumi.Input[str] vswitch_id: The ID of the virtual switch.
        """
        if alternative_endpoints is not None:
            pulumi.set(__self__, "alternative_endpoints", alternative_endpoints)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if endpoint is not None:
            pulumi.set(__self__, "endpoint", endpoint)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if vpc_instance_id is not None:
            pulumi.set(__self__, "vpc_instance_id", vpc_instance_id)
        if vswitch_id is not None:
            pulumi.set(__self__, "vswitch_id", vswitch_id)

    @property
    @pulumi.getter(name="alternativeEndpoints")
    def alternative_endpoints(self) -> Optional[pulumi.Input[str]]:
        """
        Some old instances have both AnyTunnel and SingleTunnel enabled. When switching from AnyTunnel to SingleTunnel, the endpoints of both are retained. Therefore, one more field is required to store the Endpoint.
        """
        return pulumi.get(self, "alternative_endpoints")

    @alternative_endpoints.setter
    def alternative_endpoints(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "alternative_endpoints", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to turn on the network.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter
    def endpoint(self) -> Optional[pulumi.Input[str]]:
        """
        Domain name.
        """
        return pulumi.get(self, "endpoint")

    @endpoint.setter
    def endpoint(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "endpoint", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        The network type.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[str]]:
        """
        VPC primary key.
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="vpcInstanceId")
    def vpc_instance_id(self) -> Optional[pulumi.Input[str]]:
        """
        The vpc instance ID.
        """
        return pulumi.get(self, "vpc_instance_id")

    @vpc_instance_id.setter
    def vpc_instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vpc_instance_id", value)

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the virtual switch.
        """
        return pulumi.get(self, "vswitch_id")

    @vswitch_id.setter
    def vswitch_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vswitch_id", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetDomainExtensionsResult',
    'AwaitableGetDomainExtensionsResult',
    'get_domain_extensions',
    'get_domain_extensions_output',
]

@pulumi.output_type
class GetDomainExtensionsResult:
    """
    A collection of values returned by getDomainExtensions.
    """
    def __init__(__self__, extensions=None, frontend_port=None, id=None, ids=None, load_balancer_id=None, output_file=None):
        if extensions and not isinstance(extensions, list):
            raise TypeError("Expected argument 'extensions' to be a list")
        pulumi.set(__self__, "extensions", extensions)
        if frontend_port and not isinstance(frontend_port, int):
            raise TypeError("Expected argument 'frontend_port' to be a int")
        pulumi.set(__self__, "frontend_port", frontend_port)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if load_balancer_id and not isinstance(load_balancer_id, str):
            raise TypeError("Expected argument 'load_balancer_id' to be a str")
        pulumi.set(__self__, "load_balancer_id", load_balancer_id)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)

    @property
    @pulumi.getter
    def extensions(self) -> Sequence['outputs.GetDomainExtensionsExtensionResult']:
        """
        A list of SLB domain extension. Each element contains the following attributes:
        """
        return pulumi.get(self, "extensions")

    @property
    @pulumi.getter(name="frontendPort")
    def frontend_port(self) -> int:
        return pulumi.get(self, "frontend_port")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="loadBalancerId")
    def load_balancer_id(self) -> str:
        return pulumi.get(self, "load_balancer_id")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")


class AwaitableGetDomainExtensionsResult(GetDomainExtensionsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDomainExtensionsResult(
            extensions=self.extensions,
            frontend_port=self.frontend_port,
            id=self.id,
            ids=self.ids,
            load_balancer_id=self.load_balancer_id,
            output_file=self.output_file)


def get_domain_extensions(frontend_port: Optional[int] = None,
                          ids: Optional[Sequence[str]] = None,
                          load_balancer_id: Optional[str] = None,
                          output_file: Optional[str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDomainExtensionsResult:
    """
    This data source provides the domain extensions associated with a server load balancer listener.

    > **NOTE:** Available in 1.60.0+

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    foo = alicloud.slb.get_domain_extensions(ids=["fake-de-id"],
        load_balancer_id="fake-lb-id",
        frontend_port="fake-port")
    ```


    :param int frontend_port: The frontend port used by the HTTPS listener of the SLB instance. Valid values: 1–65535.
    :param Sequence[str] ids: IDs of the SLB domain extensions.
    :param str load_balancer_id: The ID of the SLB instance.
    """
    __args__ = dict()
    __args__['frontendPort'] = frontend_port
    __args__['ids'] = ids
    __args__['loadBalancerId'] = load_balancer_id
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:slb/getDomainExtensions:getDomainExtensions', __args__, opts=opts, typ=GetDomainExtensionsResult).value

    return AwaitableGetDomainExtensionsResult(
        extensions=pulumi.get(__ret__, 'extensions'),
        frontend_port=pulumi.get(__ret__, 'frontend_port'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        load_balancer_id=pulumi.get(__ret__, 'load_balancer_id'),
        output_file=pulumi.get(__ret__, 'output_file'))
def get_domain_extensions_output(frontend_port: Optional[pulumi.Input[int]] = None,
                                 ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                 load_balancer_id: Optional[pulumi.Input[str]] = None,
                                 output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetDomainExtensionsResult]:
    """
    This data source provides the domain extensions associated with a server load balancer listener.

    > **NOTE:** Available in 1.60.0+

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    foo = alicloud.slb.get_domain_extensions(ids=["fake-de-id"],
        load_balancer_id="fake-lb-id",
        frontend_port="fake-port")
    ```


    :param int frontend_port: The frontend port used by the HTTPS listener of the SLB instance. Valid values: 1–65535.
    :param Sequence[str] ids: IDs of the SLB domain extensions.
    :param str load_balancer_id: The ID of the SLB instance.
    """
    __args__ = dict()
    __args__['frontendPort'] = frontend_port
    __args__['ids'] = ids
    __args__['loadBalancerId'] = load_balancer_id
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:slb/getDomainExtensions:getDomainExtensions', __args__, opts=opts, typ=GetDomainExtensionsResult)
    return __ret__.apply(lambda __response__: GetDomainExtensionsResult(
        extensions=pulumi.get(__response__, 'extensions'),
        frontend_port=pulumi.get(__response__, 'frontend_port'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        load_balancer_id=pulumi.get(__response__, 'load_balancer_id'),
        output_file=pulumi.get(__response__, 'output_file')))
